@@ -1,7 +1,7 @@
 #!perl
 
 # gmetric proxy which consumes metric samples consisting of absolute values and
-# re-emits aggregated rate metrics to gmond instead
+# re-emits time-aggregated rate metrics to gmond instead
 
 use strict;
 use warnings;
@@ -20,30 +20,37 @@ $me $Ganglia::Gmetric::PP::VERSION
 
 Usage: $me [OPTIONS]...
 
-  -h, --remote-host=STRING  Remote host where gmond is running (required)
-  -p, --remote-port=INT     Remote port where gmond is running. Default 8649
-  -H, --listen-host=STRING  Local interface to listen on. Default 0.0.0.0
-  -P, --listen-port=INT     Local UDP port to listen on. Default 18649
-  -n, --period=INT          Time period in seconds between aggregations. Default 60
-  -s, --suffix=STRING       Suffix to append to gmetric units. Default "/s"
-  -f, --[no]-floating       Always use "double" type instead of original metrics' types. Default on
-  -d, --daemon              Run in daemon mode.
-  -g, --debug               Display debugging output
-  --help                    Print help and exit
+  -h, --remote-host=STRING   Remote host where gmond is running. Default localhost
+  -p, --remote-port=INT      Remote port where gmond is running. Default 8649
+  -H, --listen-host=STRING   Local interface to listen on. Default 0.0.0.0
+  -P, --listen-port=INT      Local UDP port to listen on. Default 18649
+  -u, --unit-suffix=STRING   Suffix to append to gmetric units. Default "/s"
+  -m, --metric-suffix=STRING Suffix to append to metric names. Default "_rate"
+  -n, --period=INT           Time period in seconds between aggregations. Default 60
+  -N, --multiplier=FLOAT     Amount to multiply output values by. Default 1
+                              (e.g., use "-N 3600 -u /hour" to emit per-hour metrics).
+  -f, --[no]-floating        Always use "double" type instead of original metrics' types. Default on
+  -d, --daemon               Run in daemon mode.
+  -F, --pidfile=FILE         File to write PID to in daemon mode.
+  -g, --debug                Display debugging output
+  --help                     Print help and exit
 EOU
     exit 1;
 }
 
 Getopt::Long::Configure('no_ignore_case');
 GetOptions(
-    'h|remote-host=s'   => \(my $remote_host),
+    'h|remote-host=s'   => \(my $remote_host    = '127.0.0.1'),
     'p|remote-port=i'   => \(my $remote_port    = 8649),
     'H|listen-host=s'   => \(my $listen_host    = '0.0.0.0'),
     'P|listen-port=i'   => \(my $listen_port    = 18649),
+    'u|unit-suffix=s'   => \(my $units_suffix   = '/s'),
+    'm|metric-suffix=s' => \(my $metric_suffix  = '_rate'),
     'n|period=i'        => \(my $period         = 60),
-    's|suffix=s'        => \(my $units_suffix   = '/s'),
+    'N|multiplier=i'    => \(my $multiplier     = 1.0),
     'f|floating!'       => \(my $output_doubles = 1),
     'd|daemon!'         => \(my $daemonize),
+    'F|pidfile=s'       => \(my $pidfile),
     'g|debug'           => \(my $debug),
     'help!'             => \(my $help),
 ) || usage;
@@ -64,6 +71,17 @@ else {
     die "need either AnyEvent or Danga::Socket module";
 }
 
+if ($daemonize) {
+    die "Proc::Daemon not available" unless eval "use Proc::Daemon; 1";
+    Proc::Daemon::Init();
+}
+
+if ($pidfile && open my $pid_fh, '>', $pidfile) {
+    print $pid_fh "$$\n";
+    close $pid_fh;
+}
+END { unlink $pidfile if $pidfile }
+
 my $emitter = Ganglia::Gmetric::PP->new(
     host => $remote_host,
     port => $remote_port,
@@ -128,12 +146,14 @@ sub aggregator {
                 $aggregate[METRIC_INDEX_VALUE] = int($aggregate[METRIC_INDEX_VALUE])
             }
 
+            $aggregate[METRIC_INDEX_NAME]  .= $metric_suffix;
             $aggregate[METRIC_INDEX_UNITS] .= $units_suffix;
+            $aggregate[METRIC_INDEX_VALUE] *= $multiplier;
             $aggregate[METRIC_INDEX_TMAX] = $period;
 
             $emitter->send(@aggregate);
 
-            $debug && warn Data::Dumper->Dump([\@aggregate], ["${metric}_aggregated"]);
+            $debug && warn Data::Dumper->Dump([\@aggregate], [$metric]);
         }
         %metric_aggregates = ();
 
@@ -148,11 +168,6 @@ sub aggregator {
     }
 }
 
-if ($daemonize) {
-    die "Proc::Daemon not available" unless eval "use Proc::Daemon; 1";
-    Proc::Daemon::Init();
-}
-
 # run event loop
 if ($use_anyevent) {
     $timer = AnyEvent->timer(after => $period, cb => \&aggregator);
